@@ -56,5 +56,8 @@ class Circle(RoundRect):
                     ``None`` for no outline.
 
     """
+
     def __init__(self, x0, y0, r, *, fill=None, outline=None):
-        super().__init__(x0-r, y0-r, 2*r+1, 2*r+1, r, fill=fill, outline=outline)
+        super().__init__(
+            x0 - r, y0 - r, 2 * r + 1, 2 * r + 1, r, fill=fill, outline=outline
+        )
